/**
 * @athenna/core
 *
 * (c) João Lenon <lenon@athenna.io>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { Exec, File, Folder } from '@athenna/common';
import { BaseCommand, Option } from '@athenna/artisan';
export class BuildCommand extends BaseCommand {
    clean;
    ignoreOnClean;
    static signature() {
        return 'build';
    }
    static description() {
        return 'Compile your application code to JavaScript.';
    }
    async handle() {
        if (this.clean) {
            const folder = await new Folder(Path.pwd()).load();
            const files = folder.getFilesByPattern(`!(${this.ignoreOnClean})/**/*.@(js|d.ts)`);
            await Exec.concurrently(files, file => file.remove()).then(() => this.logger.success('Application successfully cleaned.'));
            return;
        }
        const tsConfig = await this.getTsConfig();
        await Exec.command(`${Path.bin('tsc')} --project ${tsConfig.path}`).then(() => this.logger.success('Application successfully compiled.'));
    }
    getTsConfig() {
        const path = Config.get('rc.commandsManifest.build.tsconfig', '../../tmp/tsconfig.build.json');
        const content = {
            extends: this.toPosix(Path.pwd('tsconfig.json')),
            include: [this.toPosix(Path.pwd('**/*'))],
            exclude: [this.toPosix(Path.tests()), this.toPosix(Path.nodeModules())],
        };
        return new File(path, JSON.stringify(content, null, 2)).load();
    }
    toPosix(path) {
        if (process.platform === 'win32') {
            return path.replace(/\\/g, '/').slice(2);
        }
        return path;
    }
}
__decorate([
    Option({
        signature: '--clean',
        description: 'Clean all .js and .d.ts files instead of building your code.',
        default: false,
    })
], BuildCommand.prototype, "clean", void 0);
__decorate([
    Option({
        signature: '--ignore-on-clean [folders]',
        description: 'Ignore the given folders when cleaning the application.',
        default: 'tests|node_modules',
    })
], BuildCommand.prototype, "ignoreOnClean", void 0);
